@@ -2,7 +2,7 @@ from GoodCalculator.calculator import Calculator
 # import sys
 import click
 
-@run_cli.command()
+@click.command()
 @click.argument('equation')
 def run_cli(equation):
 	calc = Calculator()
